export interface StorageInterface {
  saveUserDataText(fileName: string, content: any): Promise<void>
  saveUserDataJson(fileName: string, content: any): Promise<void>
  saveConfigData(content: any): Promise<void>
  readUserDataText(fileName: string): Promise<string>
  readUserDataJson(fileName: string): Promise<any>
  readConfigData(): Promise<any>
  deleteUserDataText(fileName: string): Promise<void>
  deleteUserDataJson(fileName: string): Promise<void>
}
